Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(711)

Unified Diff: content/browser/utility_process_host_impl.h

Issue 2096643002: Eliminate MojoApplicationHost (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mah3
Patch Set: . Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/utility_process_host_impl.h
diff --git a/content/browser/utility_process_host_impl.h b/content/browser/utility_process_host_impl.h
index ad1ebccb709cbf2ef69e7bc03c1f77a1201efe40..88deabb1af3e03fb0d118a9855ce7b7ba7161a3f 100644
--- a/content/browser/utility_process_host_impl.h
+++ b/content/browser/utility_process_host_impl.h
@@ -26,7 +26,7 @@ class Thread;
namespace content {
class BrowserChildProcessHostImpl;
class InProcessChildThreadParams;
-class MojoApplicationHost;
+class MojoChildConnection;
typedef base::Thread* (*UtilityMainThreadFactoryFunction)(
const InProcessChildThreadParams&);
@@ -58,7 +58,8 @@ class CONTENT_EXPORT UtilityProcessHostImpl
void SetEnv(const base::EnvironmentMap& env) override;
#endif
bool Start() override;
- ServiceRegistry* GetServiceRegistry() override;
+ shell::InterfaceRegistry* GetInterfaceRegistry() override;
+ shell::InterfaceProvider* GetRemoteInterfaces() override;
void SetName(const base::string16& name) override;
void set_child_flags(int flags) { child_flags_ = flags; }
@@ -118,9 +119,9 @@ class CONTENT_EXPORT UtilityProcessHostImpl
std::unique_ptr<base::Thread> in_process_thread_;
// Browser-side Mojo endpoint which sets up a Mojo channel with the child
// process and contains the browser's ServiceRegistry.
const std::string child_token_;
- std::unique_ptr<MojoApplicationHost> mojo_application_host_;
+ std::unique_ptr<MojoChildConnection> mojo_child_connection_;
// Used to vend weak pointers, and should always be declared last.
base::WeakPtrFactory<UtilityProcessHostImpl> weak_ptr_factory_;
« no previous file with comments | « content/browser/service_worker/embedded_worker_test_helper.cc ('k') | content/browser/utility_process_host_impl.cc » ('j') | no next file with comments »
@@ -118,9 +119,9 @@ class CONTENT_EXPORT UtilityProcessHostImpl
std::unique_ptr<base::Thread> in_process_thread_;
// Browser-side Mojo endpoint which sets up a Mojo channel with the child
- // process and contains the browser's ServiceRegistry.
+ // process and contains the browser's shell::InterfaceRegistry.
const std::string child_token_;

Powered by Google App Engine
This is Rietveld 408576698